@@ -2,7 +2,7 @@ package Test2::API::Instance;
 use strict;
 use warnings;
 
-our $VERSION = '0.000041';
+our $VERSION = '0.000042';
 
 our @CARP_NOT = qw/Test2::API Test2::API::Instance Test2::IPC::Driver Test2::Formatter/;
 use Carp qw/confess carp/;
@@ -97,11 +97,14 @@ sub _finalize {
     unless ($self->{+FORMATTER}) {
         my ($formatter, $source);
         if ($ENV{T2_FORMATTER}) {
-            $formatter = $ENV{T2_FORMATTER};
-            $source    = "set by the 'T2_FORMATTER' environment variable";
+            $source = "set by the 'T2_FORMATTER' environment variable";
 
-            $formatter = "Test2::Formatter::$formatter"
-                unless $formatter =~ s/^\+//;
+            if ($ENV{T2_FORMATTER} =~ m/^(\+)?(.*)$/) {
+                $formatter = $1 ? $2 : "Test2::Formatter::$2"
+            }
+            else {
+                $formatter = '';
+            }
         }
         elsif (@{$self->{+FORMATTERS}}) {
             ($formatter) = @{$self->{+FORMATTERS}};
