@@ -2,7 +2,7 @@ package Test2::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.000041';
+our $VERSION = '0.000042';
 
 use Test2::Util::HashBase qw/trace nested in_subtest/;
 use Test2::Util::ExternalMeta qw/meta get_meta set_meta delete_meta/;
@@ -10,6 +10,7 @@ use Test2::Util::ExternalMeta qw/meta get_meta set_meta delete_meta/;
 sub causes_fail      { 0 }
 sub increments_count { 0 }
 sub diagnostics      { 0 }
+sub no_display       { 0 }
 
 sub callback { }
 
@@ -163,6 +164,11 @@ non-verbose harness may choose to hide events that are not in this category.
 Some formatters may choose to send these to STDERR instead of STDOUT to ensure
 they are seen.
 
+=item $bool = $e->no_display
+
+False by default. This will return true on events that should not be displayed
+by formatters.
+
 =back
 
 =head1 THIRD PARTY META-DATA
